@@ -21,19 +21,29 @@ import sys
 from oslo_config import cfg
 
 import solum
-from solum.common.rpc import service
+from solum.common.rpc import service as rpc_service
+from solum.common import service
 from solum.common import trace_data
 from solum.openstack.common.gettextutils import _
 from solum.openstack.common import log as logging
+from solum.worker.handlers import default as default_handler
 from solum.worker.handlers import noop as noop_handler
 from solum.worker.handlers import shell as shell_handler
 
 LOG = logging.getLogger(__name__)
 
 
+cli_opts = [
+    cfg.IntOpt('run-container-cmd-as', metavar='UID', default=65533,
+               help='Run commands in containers as the user assigned '
+                    'with the UID, which can be used to constrain resource, '
+                    'e.g. disk usage, on a worker host.'),
+]
+
+
 def main():
-    cfg.CONF(sys.argv[1:], project='solum')
-    logging.setup('solum')
+    cfg.CONF.register_cli_opts(cli_opts)
+    service.prepare_service(sys.argv)
     solum.TLS.trace = trace_data.TraceData()
 
     LOG.info(_('Starting server in PID %s') % os.getpid())
@@ -46,6 +56,7 @@ def main():
 
     handlers = {
         'noop': noop_handler.Handler,
+        'default': default_handler.Handler,
         'shell': shell_handler.Handler,
     }
 
@@ -53,6 +64,6 @@ def main():
         handlers[cfg.CONF.worker.handler](),
     ]
 
-    server = service.Service(cfg.CONF.worker.topic,
-                             cfg.CONF.worker.host, endpoints)
+    server = rpc_service.Service(cfg.CONF.worker.topic,
+                                 cfg.CONF.worker.host, endpoints)
     server.serve()
