@@ -74,14 +74,46 @@ SERVICE_OPTS = [
                help='Deployer logs location'),
 ]
 
+
+def list_opts():
+    yield 'deployer', SERVICE_OPTS
+
+
 cfg.CONF.register_opts(SERVICE_OPTS, group='deployer')
 cfg.CONF.import_opt('image_format', 'solum.api.handlers.assembly_handler',
                     group='api')
-cfg.CONF.import_group('worker', 'solum.worker.handlers.shell')
+cfg.CONF.import_opt('image_storage', 'solum.worker.config', group='worker')
 
 deployer_log_dir = cfg.CONF.deployer.deployer_log_dir
 
 
+def save_du_ref_for_scaling(ctxt, assembly_id, du=None):
+
+    try:
+        wf = objects.registry.Workflow.get_by_assembly_id(assembly_id)
+    except sqla_exc.SQLAlchemyError as ex:
+        LOG.error("Failed to get workflow corresponding "
+                  "to assembly %s" % assembly_id)
+        LOG.exception(ex)
+        return
+
+    if wf is not None:
+        try:
+            app = objects.registry.App.get_by_id(ctxt, wf.app_id)
+            current_scale_config = app.scale_config
+            if current_scale_config:
+                current_config = current_scale_config[app.name]
+                current_config['du'] = du
+                current_scale_config[app.name] = current_config
+                scale_config = dict()
+                scale_config['scale_config'] = current_scale_config
+                objects.registry.App.update_and_save(ctxt, app.id,
+                                                     scale_config)
+        except sqla_exc.SQLAlchemyError as ex:
+            LOG.error("Failed to update app scale_config: %s" % app.id)
+            LOG.exception(ex)
+
+
 def update_wf_and_app(ctxt, assembly_id, data):
     # Update workflow and app objects
     data_dict = dict()
@@ -210,7 +242,6 @@ class Handler(object):
                 osc.heat().stacks.delete(stack_id)
             except exc.HTTPNotFound:
                 # stack already deleted
-                assem.destroy(ctxt)
                 t_logger.log(logging.ERROR, "Heat stack not found.")
                 t_logger.upload()
                 self._delete_app_artifacts_from_swift(ctxt, t_logger,
@@ -233,7 +264,6 @@ class Handler(object):
                     # Must use stack_name for expecting a 404
                     osc.heat().stacks.get(stack_name)
                 except exc.HTTPNotFound:
-                    assem.destroy(ctxt)
                     t_logger.log(logging.DEBUG, "Stack delete successful.")
                     t_logger.upload()
                     self._delete_app_artifacts_from_swift(ctxt, t_logger,
@@ -301,18 +331,46 @@ class Handler(object):
                 wait_interval *= growth_factor
 
     def destroy_app(self, ctxt, app_id):
-        # Destroy a plan's assemblies, and then the plan.
-        plan = objects.registry.Plan.get_by_id(ctxt, app_id)
+        try:
+            # Destroy a plan's assemblies, and then the plan
+            plan = objects.registry.Plan.get_by_id(ctxt, app_id)
 
-        # Fetch all assemblies by plan id, and self.destroy() them.
-        assemblies = objects.registry.AssemblyList.get_all(ctxt)
-        for assem in assemblies:
-            if app_id == assem.plan_id:
-                self.destroy_assembly(ctxt, assem.id)
+            # Fetch all assemblies by plan id, and self.destroy() them.
+            assemblies = objects.registry.AssemblyList.get_all(ctxt)
+            for assem in assemblies:
+                if app_id == assem.plan_id:
+                    self.destroy_assembly(ctxt, assem.id)
 
-        plan.destroy(ctxt)
+            plan.destroy(ctxt)
+
+        except exception.ResourceNotFound:
+            LOG.error("Plan not found for app_id", app_id)
+
+        # Get all the workflows for app_id
+        workflows = objects.registry.WorkflowList.get_all(ctxt, app_id)
+
+        # For each workflow get the assembly and call destroy assembly to
+        # remove heat stacks.
+        for workflow in workflows:
+            assemblie = objects.registry.Assembly.get_by_id(ctxt,
+                                                            workflow.assembly)
+            self.destroy_assembly(ctxt, assemblie.id)
+
+        # Delete workflow based on app_id
+        objects.registry.Workflow.destroy(app_id)
+
+        # Delete app
+        db_obj = objects.registry.App.get_by_uuid(ctxt, app_id)
+        db_obj.destroy(ctxt)
+
+    def scale(self, ctxt, assembly_id):
+        # TODO(devkulkarni) Find out scale target by querying the app table
+        # deploy that many number of dus
+        raise exception.NotImplemented()
 
     def deploy(self, ctxt, assembly_id, image_loc, image_name, ports):
+        save_du_ref_for_scaling(ctxt, assembly_id, du=image_loc)
+
         osc = clients.OpenStackClients(ctxt)
 
         assem = objects.registry.Assembly.get_by_id(ctxt,
